==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/servicecatalog/kotlin/inputs/GetProductPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.servicecatalog.kotlin.inputs

import com.pulumi.aws.servicecatalog.inputs.GetProductPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getProduct.
 * @property acceptLanguage Language code. Valid values are `en` (English), `jp` (Japanese), `zh` (Chinese). The default value is `en`.
 * @property id ID of the product.
 * The following arguments are optional:
 * @property tags Tags applied to the product.
 */
public data class GetProductPlainArgs(
    public val acceptLanguage: String? = null,
    public val id: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.servicecatalog.inputs.GetProductPlainArgs> {
    override fun toJava(): com.pulumi.aws.servicecatalog.inputs.GetProductPlainArgs =
        com.pulumi.aws.servicecatalog.inputs.GetProductPlainArgs.builder()
            .acceptLanguage(acceptLanguage?.let({ args0 -> args0 }))
            .id(id.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetProductPlainArgs].
 */
@PulumiTagMarker
public class GetProductPlainArgsBuilder internal constructor() {
    private var acceptLanguage: String? = null

    private var id: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Language code. Valid values are `en` (English), `jp` (Japanese), `zh` (Chinese). The default value is `en`.
     */
    @JvmName("gllmdlecnaagcytc")
    public suspend fun acceptLanguage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.acceptLanguage = mapped
    }

    /**
     * @param value ID of the product.
     * The following arguments are optional:
     */
    @JvmName("wcmvogpaiubslyus")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.id = mapped
    }

    /**
     * @param value Tags applied to the product.
     */
    @JvmName("crlriqwveuyqqyrw")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Tags applied to the product.
     */
    @JvmName("gqskhcjmfaumoexh")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetProductPlainArgs = GetProductPlainArgs(
        acceptLanguage = acceptLanguage,
        id = id ?: throw PulumiNullFieldException("id"),
        tags = tags,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/servicecatalog/kotlin/inputs/GetProductPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.servicecatalog.kotlin.inputs

import com.pulumi.aws.servicecatalog.inputs.GetProductPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getProduct.
 * @property acceptLanguage Language code. Valid values are `en` (English), `jp` (Japanese), `zh` (Chinese). The default value is `en`.
 * @property id ID of the product.
 * The following arguments are optional:
 * @property tags Tags applied to the product.
 */
public data class GetProductPlainArgs(
    public val acceptLanguage: String? = null,
    public val id: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.servicecatalog.inputs.GetProductPlainArgs> {
    override fun toJava(): com.pulumi.aws.servicecatalog.inputs.GetProductPlainArgs =
        com.pulumi.aws.servicecatalog.inputs.GetProductPlainArgs.builder()
            .acceptLanguage(acceptLanguage?.let({ args0 -> args0 }))
            .id(id.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetProductPlainArgs].
 */
@PulumiTagMarker
public class GetProductPlainArgsBuilder internal constructor() {
    private var acceptLanguage: String? = null

    private var id: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Language code. Valid values are `en` (English), `jp` (Japanese), `zh` (Chinese). The default value is `en`.
     */
    @JvmName("lrqhoqdxlfdxoycm")
    public suspend fun acceptLanguage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.acceptLanguage = mapped
    }

    /**
     * @param value ID of the product.
     * The following arguments are optional:
     */
    @JvmName("mmbudtpebllxptoh")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.id = mapped
    }

    /**
     * @param value Tags applied to the product.
     */
    @JvmName("ephoyohswktiyagg")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Tags applied to the product.
     */
    @JvmName("mcdicavqkanlaeek")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetProductPlainArgs = GetProductPlainArgs(
        acceptLanguage = acceptLanguage,
        id = id ?: throw PulumiNullFieldException("id"),
        tags = tags,
    )
}
